@@ -47,10 +47,9 @@ import dbus
 from dbus.mainloop.glib import DBusGMainLoop
 DBusGMainLoop(set_as_default=True)
 
-#in query mode we won't be in X, but import needs to pass
+# in query mode we won't be in X, but import needs to pass
 if 'DISPLAY' in os.environ:
-    from gi.repository import Gtk, Gdk, GObject, GLib
-    GObject.threads_init()
+    from gi.repository import Gtk, Gdk, GObject, GLib, Atk
     from ubiquity import gtkwidgets
 
 from ubiquity import (
@@ -68,9 +67,6 @@ __pychecker__ = 'no-classattr'
 # Define global path
 PATH = os.environ.get('UBIQUITY_PATH', False) or '/usr/share/ubiquity'
 
-# Define global pixmaps location
-PIXMAPS = os.environ.get('PIXMAPS', False) or '/usr/share/pixmaps'
-
 # Define ui path
 UIDIR = os.environ.get('UBIQUITY_GLADE', False) or os.path.join(PATH, 'gtk')
 os.environ['UBIQUITY_GLADE'] = UIDIR
@@ -155,6 +151,9 @@ class Controller(ubiquity.frontend.base.Controller):
     def toggle_next_button(self, label='gtk-go-forward'):
         self._wizard.toggle_next_button(label)
 
+    def toggle_skip_button(self, label='skip'):
+        self._wizard.toggle_skip_button(label)
+
     def switch_to_install_interface(self):
         self._wizard.switch_to_install_interface()
 
@@ -241,8 +240,6 @@ class Wizard(BaseFrontend):
         self.set_busy_cursor(True)
         atexit.register(set_root_cursor)
 
-        self.laptop = misc.execute("laptop-detect")
-
         # Are we running alongside Orca?
         with open('/proc/cmdline') as fp:
             if 'access=v3' in fp.read():
@@ -269,6 +266,9 @@ class Wizard(BaseFrontend):
               -GtkProgressBar-min-horizontal-bar-height : 10;
               -GtkProgressBar-min-horizontal-bar-width : 10;
             }
+            GtkPaned {
+                -GtkPaned-handle-size: 10;
+            }
             ''')
         Gtk.StyleContext.add_provider_for_screen(
             Gdk.Screen.get_default(),
@@ -328,6 +328,7 @@ class Wizard(BaseFrontend):
 
         for mod in self.pages:
             progress = Gtk.ProgressBar()
+            progress.get_accessible().set_role(Atk.Role.INVALID)
             progress.set_size_request(10, 10)
             progress.set_fraction(0)
             self.dot_grid.add(progress)
@@ -360,8 +361,6 @@ class Wizard(BaseFrontend):
                             AppIndicator.IndicatorStatus.ACTIVE)
                         self.indicator.set_menu(
                             self.builder.get_object('a11y_indicator_menu'))
-                        self.live_installer.connect(
-                            'key-press-event', self.a11y_profile_keys)
                         if osextras.find_on_path('canberra-gtk-play'):
                             subprocess.Popen(
                                 ['canberra-gtk-play', '--id=system-ready'],
@@ -369,6 +368,8 @@ class Wizard(BaseFrontend):
                     except:
                         print("Unable to set up accessibility profile support",
                               file=sys.stderr)
+            self.live_installer.connect(
+                'key-press-event', self.a11y_profile_keys)
 
     def all_children(self, parent):
         if isinstance(parent, Gtk.Container):
@@ -667,6 +668,10 @@ class Wizard(BaseFrontend):
         elif (event.state & Gdk.ModifierType.CONTROL_MASK and
                 event.keyval == Gdk.keyval_from_name('s')):
             self.a11y_profile_screen_reader_activate()
+        elif (event.state & Gdk.ModifierType.SUPER_MASK and
+                event.state & Gdk.ModifierType.MOD1_MASK and
+                event.keyval == Gdk.keyval_from_name('s')):
+            self.a11y_profile_screen_reader_activate()
 
     def a11y_profile_high_contrast_activate(self, widget=None):
         subprocess.call(['log-output', '-t', 'ubiquity',
@@ -721,7 +726,7 @@ class Wizard(BaseFrontend):
 
         if 'UBIQUITY_ONLY' in os.environ:
             self.disable_logout_indicator()
-            if not 'UBIQUITY_DEBUG' in os.environ:
+            if 'UBIQUITY_DEBUG' not in os.environ:
                 self.disable_terminal()
 
         # show interface
@@ -888,8 +893,7 @@ class Wizard(BaseFrontend):
     def customize_installer(self):
         """Initial UI setup."""
 
-        self.live_installer.set_default_icon_from_file(
-            os.path.join(PIXMAPS, 'ubiquity.png'))
+        self.live_installer.set_icon_name('ubiquity')
         for eventbox in ['title_eventbox', 'progress_eventbox',
                          'install_details_expander']:
             box = self.builder.get_object(eventbox)
@@ -1017,7 +1021,7 @@ class Wizard(BaseFrontend):
         self.quit.hide()
         f = (Gdk.WMFunction.RESIZE | Gdk.WMFunction.MAXIMIZE |
              Gdk.WMFunction.MOVE)
-        if not 'UBIQUITY_ONLY' in os.environ:
+        if 'UBIQUITY_ONLY' not in os.environ:
             f |= Gdk.WMFunction.MINIMIZE
         self.live_installer.get_window().set_functions(f)
         self.allow_change_step(False)
@@ -1046,7 +1050,7 @@ class Wizard(BaseFrontend):
             self.quit.show()
         f = Gdk.WMFunction.RESIZE | Gdk.WMFunction.MAXIMIZE | \
             Gdk.WMFunction.MOVE | Gdk.WMFunction.CLOSE
-        if not 'UBIQUITY_ONLY' in os.environ:
+        if 'UBIQUITY_ONLY' not in os.environ:
             f |= Gdk.WMFunction.MINIMIZE
         self.refresh()
 
@@ -1242,6 +1246,10 @@ class Wizard(BaseFrontend):
             self.next.set_label(label)
             self.translate_widget(self.next)
 
+    def toggle_skip_button(self, label='skip'):
+        self.skip.set_label(self.get_string(label))
+        self.skip.show()
+
     def set_page(self, n):
         self.run_automation_error_cmd()
         # We only stop the backup process when we're on a page where questions
@@ -1276,6 +1284,8 @@ class Wizard(BaseFrontend):
                     cur = page.optional_widgets[0]
                 if cur:
                     self.set_page_title(page)
+                    self.skip.set_visible(
+                        hasattr(page.ui, 'plugin_on_skip_clicked'))
                     cur.show()
                     is_install = page.ui.get('plugin_is_install')
                     break
@@ -1424,6 +1434,11 @@ class Wizard(BaseFrontend):
     def on_live_installer_delete_event(self, widget, unused_event):
         return self.on_quit_clicked(widget)
 
+    def on_skip_clicked(self, unused_widget):
+        ui = self.pages[self.pagesindex].ui
+        if hasattr(ui, 'plugin_on_skip_clicked'):
+            ui.plugin_on_skip_clicked()
+
     def on_next_clicked(self, unused_widget):
         """Callback to control the installation process between steps."""
         if not self.allowed_change_step or not self.allowed_go_forward:
