@@ -64,10 +64,12 @@ class PartMan(QtGui.QWidget):
             if item in disk_cache:
                 # the item is a disk
                 indexCount += 1
-                partition_bar = PartitionsBar(self.part_advanced_bar_frame)
+                partition_bar = PartitionsBar(
+                    self.part_advanced_bar_frame,
+                    controller=self.ctrlr)
                 self.part_advanced_bar_frame.layout().addWidget(partition_bar)
 
-                #hide all the other bars at first
+                # hide all the other bars at first
                 if self.active_bar:
                     partition_bar.setVisible(False)
                 else:
@@ -148,7 +150,7 @@ class PartMan(QtGui.QWidget):
                 self.on_partition_create_use_combo_changed)
 
             # TODO
-            #self.translate_widget_children(dialog)
+            # self.translate_widget_children(dialog)
 
         # TODO cjwatson 2006-11-01: Because partman doesn't use a question
         # group for these, we have to figure out in advance whether each
@@ -192,8 +194,8 @@ class PartMan(QtGui.QWidget):
         dialog.partition_create_mount_combo.clear()
         for mp, choice_c, choice in (
                 self.ctrlr.dbfilter.default_mountpoint_choices()):
-            ##FIXME gtk frontend has a nifty way of showing the user readable
-            ##'choice' text in the drop down, but only selecting the 'mp' text
+            # FIXME gtk frontend has a nifty way of showing the user readable
+            # 'choice' text in the drop down, but only selecting the 'mp' text
             dialog.partition_create_mount_combo.addItem(mp)
         dialog.partition_create_mount_combo.clearEditText()
 
@@ -229,7 +231,7 @@ class PartMan(QtGui.QWidget):
         if not hasattr(self, 'create_use_method_names'):
             return
         known_filesystems = ('ext4', 'ext3', 'ext2',
-                             'btrfs', 'reiserfs', 'jfs', 'xfs',
+                             'btrfs', 'jfs', 'xfs',
                              'fat16', 'fat32', 'ntfs', 'uboot')
         text = str(self.create_dialog.partition_create_use_combo.currentText())
         if text not in self.create_use_method_names:
@@ -250,7 +252,7 @@ class PartMan(QtGui.QWidget):
         if not self.ctrlr.allowed_change_step():
             return
 
-        #lazy loading
+        # lazy loading
         dialog = self.edit_dialog
         if not dialog:
             self.edit_dialog = QtGui.QDialog(self)
@@ -260,7 +262,7 @@ class PartMan(QtGui.QWidget):
                 self.on_partition_edit_use_combo_changed)
 
             # TODO
-            #self.translate_widget_children(dialog)
+            # self.translate_widget_children(dialog)
 
         current_size = None
         if ('can_resize' not in partition or not partition['can_resize'] or
@@ -373,7 +375,7 @@ class PartMan(QtGui.QWidget):
         # point makes no sense. TODO cjwatson 2007-01-31: Unfortunately we
         # have to hardcode the list of known filesystems here.
         known_filesystems = ('ext4', 'ext3', 'ext2',
-                             'btrfs', 'reiserfs', 'jfs', 'xfs',
+                             'btrfs', 'jfs', 'xfs',
                              'fat16', 'fat32', 'ntfs', 'uboot')
         text = str(self.edit_dialog.partition_edit_use_combo.currentText())
         if text not in self.edit_use_method_names:
@@ -418,7 +420,7 @@ class PartMan(QtGui.QWidget):
             if 'can_new' in partition and partition['can_new']:
                 self.partman_create_dialog(devpart, partition)
 
-    ### actions for clicking the buttons ###
+    # actions for clicking the buttons
 
     def get_treeview_data(self):
         selected = self.partition_list_treeview.selectedIndexes()
