@@ -58,13 +58,16 @@ PATH = '/usr/share/ubiquity'
 # Define locale path
 LOCALEDIR = "/usr/share/locale"
 
-#currently using for testing, will remove
+# currently using for testing, will remove
 UIDIR = os.path.join(PATH, 'qt')
 
 
 class UbiquityUI(QtGui.QMainWindow):
     def __init__(self, parent=None):
         QtGui.QMainWindow.__init__(self, parent)
+        # app.ui MainWindow now hardcoded to 1000px wide for main
+        # content this will look bad on high res displays and should be
+        # defined by dpi not pixels
         uic.loadUi(os.path.join(UIDIR, "app.ui"), self)
 
         # QProcessManager sets a SIGCHLD handler without SA_RESTART; this
@@ -76,7 +79,7 @@ class UbiquityUI(QtGui.QMainWindow):
         distro_name = "Kubuntu"
         distro_release = ""
 
-        ## setup the release and codename
+        # # setup the release and codename
         with open("/etc/lsb-release", 'r') as fp:
             for line in fp:
                 if "DISTRIB_ID=" in line:
@@ -150,10 +153,23 @@ class Wizard(BaseFrontend):
         self.previous_excepthook = sys.excepthook
         sys.excepthook = self.excepthook
 
+        # Hardcode the KDE platform plugin to get Oxygen palette. Without this,
+        # Ubiquity uses the default Windows-95-like palette when running as a
+        # DM.
+        os.environ["QT_PLATFORM_PLUGIN"] = "kde"
+        # For above settings to apply automatically we need to indicate that we
+        # are inside a full KDE session.
+        os.environ["KDE_FULL_SESSION"] = "TRUE"
+
         self.app = QtGui.QApplication([])
+        # The "hicolor" icon theme gets picked when Ubiquity is running as a
+        # DM. This causes some icons to be missing. Hardcode the theme name to
+        # prevent that.
+        QtGui.QIcon.setThemeName(self.getIconTheme())
+        self.app.setStyle(self.getWidgetTheme())
         self._apply_stylesheet()
 
-        self.app.setWindowIcon(QtGui.QIcon.fromTheme("ubiquity"))
+        self.app.setWindowIcon(QtGui.QIcon.fromTheme("ubiquity-kde"))
         import dbus.mainloop.qt
         dbus.mainloop.qt.DBusQtMainLoop(set_as_default=True)
 
@@ -165,12 +181,15 @@ class Wizard(BaseFrontend):
         self.ui.content_widget.setVisible(False)
 
         if 'UBIQUITY_GREETER' in os.environ:
-            self.ui.setWindowState(
-                self.ui.windowState() ^ QtCore.Qt.WindowFullScreen)
+            self.ui.setWindowFlags(
+                QtCore.Qt.Dialog
+                | QtCore.Qt.CustomizeWindowHint
+                | QtCore.Qt.WindowTitleHint
+                )
 
         self.ui.setWizard(self)
 
-        self.stackLayout = QtGui.QStackedLayout(self.ui.widgetStack)
+        self.stackLayout = QtGui.QStackedLayout(self.ui.content_widget)
 
         self.pages = []
         self.pagesindex = 0
@@ -247,8 +266,6 @@ class Wizard(BaseFrontend):
 
         self.set_busy_cursor(True)
 
-        self.laptop = misc.execute("laptop-detect")
-
         # set default language
         self.locale = i18n.reset_locale(self)
 
@@ -279,7 +296,6 @@ class Wizard(BaseFrontend):
             self.ui.install_process_label.hide()
             self.breadcrumb_install.hide()
 
-        self.ui.pageMode.setCurrentWidget(self.ui.setup_page)
         self.update_back_button()
         self.update_next_button(install_now=False)
         self.ui.quit.setIcon(QtGui.QIcon.fromTheme("dialog-close"))
@@ -300,8 +316,7 @@ class Wizard(BaseFrontend):
         widget = Breadcrumb()
         widget.setObjectName(name)
         layout = self.ui.steps_widget.layout()
-        # "- 1" to insert before the bottom spacer
-        layout.insertWidget(layout.count() - 1, widget)
+        layout.addWidget(widget)
         return widget
 
     def _apply_stylesheet(self):
@@ -399,7 +414,7 @@ class Wizard(BaseFrontend):
         # Start the interface
         self.set_current_page(0)
 
-        if not 'UBIQUITY_AUTOMATIC' in os.environ:
+        if 'UBIQUITY_AUTOMATIC' not in os.environ:
             # Only show now so that the window does not show empty, then resize
             # itself and show content
             self.ui.show()
@@ -415,20 +430,23 @@ class Wizard(BaseFrontend):
             if self.current_page is None:
                 break
 
-            self.backup = False
             page = self.pages[self.pagesindex]
+            skip = False
+            if hasattr(page.ui, 'plugin_skip_page'):
+                if page.ui.plugin_skip_page():
+                    skip = True
             automatic = False
             if hasattr(page.ui, 'is_automatic'):
                 automatic = page.ui.is_automatic
 
-            if not page.filter_class:
+            if not skip and not page.filter_class:
                 # This page is just a UI page
                 self.dbfilter = None
                 self.dbfilter_status = None
                 if self.set_page(page.module.NAME):
                     self.allow_change_step(True)
                     self.app.exec_()
-            else:
+            elif not skip:
                 old_dbfilter = self.dbfilter
                 if issubclass(page.filter_class, Plugin):
                     ui = page.ui
@@ -529,13 +547,43 @@ class Wizard(BaseFrontend):
         else:
             self.breadcrumb_install.setState(Breadcrumb.TODO)
 
+    def _create_webview(self):
+        # HACK! For some reason, if the QWebView is created from the .ui file,
+        # the slideshow does not start (but it starts if one runs
+        # UBIQUITY_TEST_SLIDESHOW=1 ubiquity !). Creating it from the code
+        # works. I have no idea why.
+        from PyQt4.QtWebKit import QWebView
+        from PyQt4.QtWebKit import QWebPage
+
+        webView = QWebView()
+        webView.setMinimumSize(700, 420)
+        webView.setContextMenuPolicy(QtCore.Qt.NoContextMenu)
+
+# Make it transparent, see
+# http://ariya.blogspot.com/2009/04/transparent-qwebview-and-qwebpage.html
+
+        palette = webView.palette()
+        palette.setBrush(QtGui.QPalette.Base, QtCore.Qt.transparent)
+        page = webView.page()
+        page.setPalette(palette)
+        webView.setAttribute(QtCore.Qt.WA_OpaquePaintEvent, False)
+
+        page.setLinkDelegationPolicy(QWebPage.DelegateExternalLinks)
+        page.mainFrame().setScrollBarPolicy(
+            QtCore.Qt.Horizontal, QtCore.Qt.ScrollBarAlwaysOff)
+        page.mainFrame().setScrollBarPolicy(
+            QtCore.Qt.Vertical, QtCore.Qt.ScrollBarAlwaysOff)
+        return webView
+
     def start_slideshow(self):
         slideshow_dir = '/usr/share/ubiquity-slideshow'
         slideshow_locale = self.slideshow_get_available_locale(slideshow_dir,
                                                                self.locale)
         slideshow_main = os.path.join(slideshow_dir, 'slides', 'index.html')
         if not os.path.exists(slideshow_main) or self.hide_slideshow:
-            self.ui.pageMode.hide()
+            placeHolder = QtGui.QWidget()
+            self.stackLayout.addWidget(placeHolder)
+            self.stackLayout.setCurrentWidget(placeHolder)
             return
 
         parameters = []
@@ -546,32 +594,18 @@ class Wizard(BaseFrontend):
             parameters.append('rtl')
         parameters_encoded = '&'.join(parameters)
 
-        slides = 'file://%s#%s' % (slideshow_main, parameters_encoded)
-
-        # HACK! For some reason, if the QWebView is created from the .ui file,
-        # the slideshow does not start (but it starts if one runs
-        # UBIQUITY_TEST_SLIDESHOW=1 ubiquity !). Creating it from the code
-        # works. I have no idea why.
-        from PyQt4.QtWebKit import QWebView
-        from PyQt4.QtWebKit import QWebPage
+        slides = 'file://%s# %s' % (slideshow_main, parameters_encoded)
 
         def openLink(qUrl):
             QtGui.QDesktopServices.openUrl(qUrl)
 
-        webView = QWebView()
-        webView.setMinimumSize(700, 420)
+        webView = self._create_webview()
         webView.linkClicked.connect(openLink)
-        webView.setContextMenuPolicy(QtCore.Qt.NoContextMenu)
-        webView.page().setLinkDelegationPolicy(QWebPage.DelegateExternalLinks)
-        webView.page().mainFrame().setScrollBarPolicy(
-            QtCore.Qt.Horizontal, QtCore.Qt.ScrollBarAlwaysOff)
-        webView.page().mainFrame().setScrollBarPolicy(
-            QtCore.Qt.Vertical, QtCore.Qt.ScrollBarAlwaysOff)
         webView.load(QtCore.QUrl(slides))
 
         self.ui.navigation.hide()
-        self.ui.install_page.layout().addWidget(webView)
-        self.ui.pageMode.setCurrentWidget(self.ui.install_page)
+        self.stackLayout.addWidget(webView)
+        self.stackLayout.setCurrentWidget(webView)
 
     def set_layout_direction(self, lang=None):
         if not lang:
@@ -617,11 +651,11 @@ class Wizard(BaseFrontend):
                 for c in self.all_children(w):
                     widgets.append((c, prefix))
 
-        #if not just_current:
-        #for toplevel in self.toplevels:
-            #if toplevel.name != 'live_installer':
-                #for c in self.all_children(toplevel):
-                    #widgets.append((c, None))
+        # if not just_current:
+        # for toplevel in self.toplevels:
+            # if toplevel.name != 'live_installer':
+                # for c in self.all_children(toplevel):
+                    # widgets.append((c, None))
         self.translate_widgets(lang=lang, widgets=widgets, reget=reget)
         # Allow plugins to provide a hook for translation.
         for p in pages:
@@ -698,7 +732,7 @@ class Wizard(BaseFrontend):
     def translate_widget(self, widget, lang=None, prefix=None):
         if lang is None:
             lang = self.locale
-        #FIXME needs translations for Next, Back and Cancel
+        # FIXME needs translations for Next, Back and Cancel
         if not isinstance(widget, QtGui.QWidget):
             return
 
@@ -845,11 +879,15 @@ class Wizard(BaseFrontend):
 
     def set_page(self, n):
         self.run_automation_error_cmd()
+        # We only stop the backup process when we're on a page where questions
+        # need to be asked, otherwise you wont be able to back up past
+        # pages that do not stop on questions or are preseeded away.
+        self.backup = False
         self.ui.show()
 
-        #set all the steps active
-        #each step will set its previous ones as inactive
-        #this handles the ability to go back
+        # set all the steps active
+        # each step will set its previous ones as inactive
+        # this handles the ability to go back
 
         is_install = False
         for page in self.pages:
@@ -1178,7 +1216,7 @@ class Wizard(BaseFrontend):
 
     def debconffilter_done(self, dbfilter):
         # processing events here prevents GUI from hanging until mouse moves
-        # (LP #556376)
+        # (LP # 556376)
         self.app.processEvents()
         if not dbfilter.status:
             self.find_next_step(dbfilter.__module__)
@@ -1344,3 +1382,17 @@ class Wizard(BaseFrontend):
     # returns the current wizard page
     def get_current_page(self):
         return self.stackLayout.indexOf(self.stackLayout.currentWidget())
+
+    # use breeze widgets if using Plasma 5
+    def getWidgetTheme(self):
+        if os.path.isfile("/usr/bin/plasmashell"):
+            return "breeze"
+        else:
+            return "Oxygen"
+
+    # use breeze icons if using Plasma 5
+    def getIconTheme(self):
+        if os.path.isfile("/usr/bin/plasmashell"):
+            return "breeze"
+        else:
+            return "oxygen"
